import {
    useLoaderData
} from "react-router-dom";

import { Grid, GridItem, Heading } from "@chakra-ui/react";
import NavBar from "../components/NavBar";
import CharacterCard from "../components/CharacterCard";
import { getCharacters } from "../api/characters";

export async function loader(){
    const characters = await getCharacters();
    return { characters };
}

const Root = () => {
    const { characters } = useLoaderData();

    return (
        <>
            <NavBar />
            <Grid
                templateColumns={["repeat(1, 1fr)", "repeat(2, 1fr)", "repeat(4, 1fr)", "repeat(6, 1fr)", "repeat(8, 1fr)"]}
                ml="1.5rem"
                mr="1.5rem"
                gridGap="1rem"
            >
                <GridItem colStart={1} colEnd={-1}>
                    <Heading size="md" noOfLines={1}>Characters</Heading>
                </GridItem>
                {characters.length ? (
                    characters.map((character) => (
                        <GridItem key={character.id}>
                            <CharacterCard
                                charId={character.id}
                                image={character.image}
                                alt={"Image of " + character.name}
                                name={character.name}
                                creator={character.creator}
                                description={character.description}
                            />
                        </GridItem>
                    ))
                ) : (
                    <GridItem>
                        <p>No characters found!</p>
                    </GridItem>
                )}
            </Grid>
        </>
    );
};

export default Root;